<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nom_Programme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Utilisation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>Add New Application</source>
        <translation>Ajouter une nouvelle application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Add application</source>
        <translation>Ajouter une application</translation>
    </message>
    <message>
        <source>Delete last added application</source>
        <translation type="vanished">Effacer la dernière application ajoutée</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Border</source>
        <translation>Contour</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <location filename="../mainwindow.cpp" line="573"/>
        <location filename="../mainwindow.cpp" line="704"/>
        <source>Select...</source>
        <translation>Sélection...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>Background</source>
        <translation>Arrière-plan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>Select icon...</source>
        <translation>Choix d&apos;une icone...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Dock Preview</source>
        <translation>Prévisualisation du Dock</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>Display help </source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="304"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. Ajoutez une par une les applications au dock
2. Choisissez un fichier .desktop ou entrez une commande pour l&apos;application voulue
3. Choisissez les caractéristiques de l&apos;icone, la taille, le fond (noir par défaut) et le contour
4. Appuyez sur &quot;Ajouter une application&quot; pour continuer ou &quot;Sauvegarder&quot; pour terminer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>black</source>
        <translation>noir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>white</source>
        <translation>blanc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>Cet outil va vous permettre de créer un nouveau dock avec une ou plusieurs applications. Vous pouvez aussi éditer ou supprimer un dock créé précédemment.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <source>Operation mode</source>
        <translation>Mode d&apos;opération</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <source>&amp;Create</source>
        <translation type="vanished">&amp;Créer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>Dock name</source>
        <translation>Nom du Dock</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="215"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Entrez le nom à afficher dans le Menu :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Select dock to delete</source>
        <translation>Choisissez le dock à supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Confirmation</source>
        <translation>Confirmation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Êtes-vous sûr de vouloir supprimer %1 ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Delete last application</source>
        <translation type="vanished">Effacer la dernière application</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Delete this application</source>
        <translation>Effacer cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Overwrite?</source>
        <translation>Écraser ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation>Voulez-vous écraser le fichier du dock ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Save file</source>
        <translation>Enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Dock saved</source>
        <translation>Dock sauvegardé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>Le dock a été sauvegardé.

Pour éditer ce nouveau dock veuillez choisir &apos;Editer un dock existant&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>About %1</source>
        <translation>À propos %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Description goes here</source>
        <translation>Mettre ici la description</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <source>Please select a file.</source>
        <translation type="vanished">Veuillez choisir un fichier.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="636"/>
        <source>Select .desktop file</source>
        <translation>Choisir le fichier .desktop</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="636"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>Fichiers de bureau (*.desktop)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Select a dock file</source>
        <translation>Choisir le fichier dock</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>No file selected</source>
        <translation>Pas de fichier sélectionné</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>Vous n&apos;avez choisi aucun dock à éditer.
Création d&apos;un nouveau dock.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>Could not open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Select dock to move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>Impossible d&apos;ouvrir le fichier choisi.
Création d&apos;un nouveau dock.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. Éditez les applications une par une à l&apos;aide des boutons Précédent et Suivant
2. Ajoutez ou supprimez les applications voulues
3. Une fois fait cliquez sur Sauvegarder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>Select icon</source>
        <translation>Choix de l&apos;icone</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>Icônes (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Boîte de dialogue</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Emplacement du dock</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>Tout en haut au centre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>Tout en bas à gauche</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>Tout en bas au centre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>Tout en haut à gauche</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>Tout en haut à droite</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>Au centre à gauche</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>Au centre à droite</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>Tout en bas à droite</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>A droite en haut</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>A gauche en haut</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>A gauche en bas</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>A droite en bas</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>Choisissez la position du dock</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as normal user.</source>
        <translation>Vous devez lancer cette application en tant qu&apos;utilisateur normal.</translation>
    </message>
</context>
</TS>
